@@ -55,7 +55,8 @@ from __future__ import print_function
 #import kmcos.types
 #import kmcos.io
 
-__version__ = "0.0.51"
+
+__version__ = "0.0.64"
 VERSION = __version__
 
 def evaluate_param_expression(param, parameters={}):
@@ -440,9 +441,13 @@ def evaluate_rate_expression(rate_expr, parameters={}):
 
     return rate_const
 
-def compile(kmc_model):
+def compile(kmc_model): #exports the kmc_model.xml file
     import kmcos
-    kmcos.export(kmc_model.filename + ' -b' + kmc_model.backend)
+    kmcos.export(kmc_model.filename + ' -b' + kmc_model.backend + ' ' + kmc_model.compile_options) # You can find these various compile_options in get_options() in kmcos/cli.py
+
+def create_kmc_model(model_name = None): #pointer to create_kmc_model in types.py, which creates the kmc_model
+    from kmcos.types import create_kmc_model
+    return create_kmc_model(model_name)
 
 #kmcos can be invoked directly from the command line in one of the following ways::
 #    kmcos [help] (all|benchmark|build|edit|export|help|import|rebuild|run|settings-export|shell|version|view|xml) [options]
